@@ -21,6 +21,7 @@
 
 #include "llapi/bsdf.h"
 #include "llapi/material.h"
+#include "llapi/vector.h"
 #include "hlapi/plugin_manager.h"
 
 class TBsdfLambertian : public TBsdf
@@ -38,6 +39,13 @@ class TBsdfLambertian : public TBsdf
       return tColor * (kd * tCOSNL);
     }
 
+    void getRayDirection (const TSurfaceData& rktDATA, const TVector& rktREFLECTED, TVector& rtDIR) const
+    {
+      TVector   v = RandomVectorInSphere();
+
+      rtDIR = ( dotProduct (v, rktDATA.normal()) > 0 ) ? v : -v;
+    }
+
     string className (void) const { return "BsdfLambertian"; }
 
 };  /* class TBsdfLambertian */
